@@ -1,6 +1,6 @@
 import logging
 import numpy as np
-
+import collections
 from p4p.client.thread import Context, Disconnected
 from p4p.wrapper import Value
 from .pva_codec import decompress
@@ -19,7 +19,6 @@ class Connection(PyDMConnection):
                  protocol: Optional[str] = None, parent: Optional[QObject] = None):
         """
         Manages the connection to a channel using the P4P library. A given channel can have multiple listeners.
-
         Parameters
         ----------
         channel : PyDMChannel
@@ -33,7 +32,7 @@ class Connection(PyDMConnection):
         """
         super().__init__(channel, address, protocol, parent)
         self._connected = False
-        self.monitor = P4PPlugin.context.monitor(name=address,
+        self.monitor = P4PPlugin.context.monitor(name=self.address,
                                                  cb=self.send_new_value,
                                                  notify_disconnect=True)
         self.add_listener(channel)
@@ -49,6 +48,7 @@ class Connection(PyDMConnection):
         self._upper_warning_limit = None
         self._lower_warning_limit = None
         self._timestamp = None
+        self.nttable_data_location = PyDMPlugin.get_subfield(channel)
 
     def clear_cache(self) -> None:
         """ Clear out all the stored values of this connection. """
@@ -65,6 +65,8 @@ class Connection(PyDMConnection):
         self._lower_warning_limit = None
         self._timestamp = None
 
+        self.nttable_data_location = None 
+
     def send_new_value(self, value: Value) -> None:
         """ Callback invoked whenever a new value is received by our monitor. Emits signals based on values changed. """
         if isinstance(value, Disconnected):
@@ -79,9 +81,45 @@ class Connection(PyDMConnection):
                 self.write_access_signal.emit(True)
 
             self._value = value
+            has_value_changed_yet = False
             for changed_value in value.changedSet():
-                if changed_value == 'value':
-                    new_value = value.value
+                if changed_value == 'value' or changed_value.split('.')[0] == 'value':
+                    # NTTable has a changedSet item for each column that has changed
+                    # Since we want to send an update on any table change, let's track
+                    # if the value item has been updated yet
+                    if has_value_changed_yet:
+                        continue
+                    else:
+                        has_value_changed_yet = True
+                    
+                    if 'NTTable' in value.getID():
+                        new_value = value.value.todict()
+                    else:
+                        new_value = value.value
+                    
+                    if self.nttable_data_location:
+                        msg = f"Invalid channel... {self.nttable_data_location}"
+
+                        for value in self.nttable_data_location:
+                            if isinstance(new_value, collections.Container) and not isinstance(new_value, str):
+                                
+                                if type(value) == str:
+                                    try:
+                                        new_value = new_value[value] 
+                                        continue
+                                    except TypeError:
+                                        logger.debug('Type Error when attempting to use the given key, code will next attempt to convert the key to an int')
+                                    except KeyError:
+                                        logger.exception(msg)
+                                    
+                                    try:
+                                        new_value = new_value[int(value)] 
+                                    except ValueError:
+                                        logger.exception(msg, exc_info=True)
+                            else:
+                                logger.exception(msg, exc_info=True)
+                                raise ValueError(msg)
+
                     if new_value is not None:
                         if isinstance(new_value, np.ndarray):
                             if 'NTNDArray' in value.getID():
@@ -95,6 +133,8 @@ class Connection(PyDMConnection):
                             self.new_value_signal[int].emit(new_value)
                         elif isinstance(new_value, str):
                             self.new_value_signal[str].emit(new_value)
+                        elif isinstance(new_value, dict):
+                            self.new_value_signal[dict].emit(new_value)
                         else:
                             raise ValueError(f'No matching signal for value: {new_value} with type: {type(new_value)}')
                 # Sometimes unchanged control variables appear to be returned with value changes, so checking against
@@ -149,7 +189,6 @@ class Connection(PyDMConnection):
     def add_listener(self, channel: PyDMChannel):
         """
         Adds a listener to this connection, connecting the appropriate signals/slots to the input PyDMChannel.
-
         Parameters
         ----------
         channel : PyDMChannel
@@ -183,6 +222,10 @@ class Connection(PyDMConnection):
                 channel.value_signal[np.ndarray].connect(self.put_value, Qt.QueuedConnection)
             except KeyError:
                 pass
+            try:
+                channel.value_signal[dict].connect(self.put_value, Qt.QueuedConnection)
+            except KeyError:
+                pass
 
     def close(self):
         """ Closes out this connection. """
