@@ -16,7 +16,8 @@ from ...widgets.drawing import (deg_to_qt, qt_to_deg, PyDMDrawing,
                                 PyDMDrawingEllipse,
                                 PyDMDrawingCircle, PyDMDrawingArc,
                                 PyDMDrawingPie, PyDMDrawingChord,
-                                PyDMDrawingPolygon, PyDMDrawingPolyline)
+                                PyDMDrawingPolygon, PyDMDrawingPolyline,
+                                PyDMDrawingIrregularPolygon)
 
 from ...utilities.stylesheet import apply_stylesheet
 
@@ -131,7 +132,7 @@ def test_pydmdrawing_paintEvent(qtbot, signals, alarm_sensitive_content):
 
     Expectations:
     The paintEvent will be triggered, and the widget's brush color is correctly set.
-    
+
     NOTE: This test depends on the default stylesheet having different values for 'qproperty-brush' for different alarm states of PyDMDrawing.
 
     Parameters
@@ -762,17 +763,17 @@ def test_pydmdrawingtriangle_draw_item(qapp, qtbot, monkeypatch, width, height,
     pydm_drawingtriangle.show()
 
 # # -------------------
-# # PyDMDrawingEclipse
+# # PyDMDrawingEllipse
 # # -------------------
 @pytest.mark.parametrize("width, height, pen_width", [
     (5.0, 5.0, 0),
     (10.25, 10.25, 1.5),
     (10.25, 100.0, 5.125),
 ])
-def test_pydmdrawingeclipse_draw_item(qapp, qtbot, monkeypatch, width, height,
+def test_pydmdrawingellipse_draw_item(qapp, qtbot, monkeypatch, width, height,
                                       pen_width):
     """
-    Test the rendering of a PyDMDrawingEclipse object.
+    Test the rendering of a PyDMDrawingEllipse object.
 
     Expectations:
     The drawing of the object takes place without any problems.
@@ -790,15 +791,15 @@ def test_pydmdrawingeclipse_draw_item(qapp, qtbot, monkeypatch, width, height,
     pen_width : int
         The width of the pen stroke
     """
-    pydm_dymdrawingeclipse = PyDMDrawingEllipse()
-    qtbot.addWidget(pydm_dymdrawingeclipse)
+    pydm_dymdrawingellipse = PyDMDrawingEllipse()
+    qtbot.addWidget(pydm_dymdrawingellipse)
 
-    pydm_dymdrawingeclipse.penWidth = pen_width
+    pydm_dymdrawingellipse.penWidth = pen_width
 
     monkeypatch.setattr(PyDMDrawing, "width", lambda *args: width)
     monkeypatch.setattr(PyDMDrawing, "height", lambda *args: height)
 
-    pydm_dymdrawingeclipse.show()
+    pydm_dymdrawingellipse.show()
 
 
 # # ------------------
@@ -1113,7 +1114,7 @@ def test_pydmdrawingpolygon_calculate_drawing_points(qapp, qtbot, x, y, width,
     (-1, 27, 389, 3,  2, [(-2, -2),(384, -2)]),
     (301, 230, 99, 20,  3, [(-1, 18),(-1, -1),(97, -1)])
 ])
-def test_pydmdrawingpolyline_getPoints(qapp, qtbot, x, y, width,
+def test_pydmdrawingpolyline_getpoints(qapp, qtbot, x, y, width,
                                                       height, num_points,
                                                       expected_points):
     """
@@ -1155,10 +1156,19 @@ def test_pydmdrawingpolyline_getPoints(qapp, qtbot, x, y, width,
     drawing.show()
 
 
-@pytest.mark.parametrize("width, height", [
-    (99, 20)
+@pytest.mark.parametrize("width, height, points, num_points", [
+    (99, 20, ["-1, 18", "-1, -1", "97, -1"], 3),
+    (99, 20, ["-1, 18", "-1, -1", "97, -1", "", " ", "a b"], 3),
+    (99, 20, [[-1, 18], (-1, -1), [97, -1]], 3),
+    (99, 20, [[-1, 18], (-1, -1)], 2),
+    (99, 20, [[-1, 18], (-1, -1.1)], 2),
+    (99, 20, [[-1, 18], "-1, -1.1"], 2),
+    (99, 20, [[-1, 18], "-1, -1.1", "5"], 2),
+    (99, 20, [[-1, 18], "-1, -1.1", ""], 2),
+    (99, 20, [[-1, 18], "-1, -1.1", " "], 2),
+    (99, 20, [[-1, 18],], 0),
 ])
-def test_pydmdrawingpolyline_setPoints(qapp, qtbot, monkeypatch, width, height):
+def test_pydmdrawingpolyline_setpoints(qapp, qtbot, monkeypatch, width, height, points, num_points):
     """
     Test the rendering of a PyDMDrawingPolyline widget.
 
@@ -1175,6 +1185,10 @@ def test_pydmdrawingpolyline_setPoints(qapp, qtbot, monkeypatch, width, height):
         The width to the widget
     height : int, float
         The height of the widget
+    points : [(float, float)]
+        Requested vertices of the polygon.
+    num_points :int
+        The actual number of vertices of the polygon.
     """
     drawing = PyDMDrawingPolyline()
     qtbot.addWidget(drawing)
@@ -1182,7 +1196,59 @@ def test_pydmdrawingpolyline_setPoints(qapp, qtbot, monkeypatch, width, height):
     monkeypatch.setattr(PyDMDrawing, "width", lambda *args: width)
     monkeypatch.setattr(PyDMDrawing, "height", lambda *args: height)
 
-    drawing.setPoints(["-1, 18","-1, -1","97, -1"])
+    drawing.setPoints(points)
+    assert len(drawing.getPoints()) == num_points
+
+    drawing.show()
+
+
+# # ---------------------------
+# # PyDMDrawingIrregularPolygon
+# # ---------------------------
+@pytest.mark.parametrize("num_points, points", [
+    (3, [(-2, -2), (384, -2)]),
+    (3, [(-2, -2), (384, -2), (-2, -2)]),
+    (4, [(-1, 18), (-1, -1), (97, -1)]),
+    (4, [(-1, 18), (-1, -1), "97, -1"]),
+    (4, [(-1, 18), (-1, -1), "97, -1", "-1, 18"]),
+    (4, [(-1, 18), (-1, -1), "97, -1", "-1    18"]),
+    (4, [(-1, 18), (-1, -1), "97, -1", "-1    18", (-1, 18)]),
+    (4, [(-1, 18), (-1, -1), "97, -1", "5"]),
+    (4, [(-1, 18), (-1, -1), "97, -1", ""]),
+    (4, [(-1, 18), (-1, -1), "97, -1", " "]),
+    (None, [(-2, -2), ]),
+])
+def test_pydmdrawingirregularpolygon_get_set_resetpoints(qapp, qtbot, num_points, points):
+    """
+    Test the calculations of the point coordinates of a PyDMDrawingIrregularPolygon widget.
+
+    Expectations:
+    The number of points is correct for a closed polygon.
+
+    Parameters
+    ----------
+    qtbot : fixture
+        Window for widget testing
+    num_points : int
+        The number of points in the polygon
+    points : tuple
+        The collection of the x and y coordinate sets
+    """
+    drawing = PyDMDrawingIrregularPolygon()
+    qtbot.addWidget(drawing)
+
+    assert drawing.getPoints() == []
+
+    drawing.setPoints(points)
+    vertices = drawing.getPoints()
+    if num_points is None:
+        assert vertices == []
+    else:
+        assert len(vertices) == num_points, f"points={points}"
+        assert vertices[0] == vertices[-1]  # closed polygon
+
+    drawing.resetPoints()
+    assert drawing.getPoints() == []
 
     drawing.show()
 
