@@ -17,7 +17,7 @@ from qtpy import QtCore, QtGui, QtWidgets
 from . import colors, macro, shortcuts
 from .connection import close_widget_connections, establish_widget_connections
 from .iconfont import IconFont
-from .remove_protocol import protocol_and_address, remove_protocol
+from .remove_protocol import protocol_and_address, remove_protocol, parsed_address
 from .units import convert, find_unit_options, find_unittype
 
 logger = logging.getLogger(__name__)
